Learn R Programming

sorcering (version 1.2.2)

RothC_Cin_ex_sl: Carbon Input Data for RothC using multiple sites

Description

Fictional carbon input for the RothC SOC model. The input data constists of a list of 3 matrices. Matrix columns stand for pools and matrix rows for simulation time steps.

Usage

RothC_Cin_ex_sl

Arguments

Format

A list of 3 matrices with 5 columns and 60 rows each

See Also

sorcering.