RothC_Cin_ex_sl_spin: Carbon Input Data for RothC using multiple sites with spinup run
Description
Fictional carbon input for the RothC SOC model. The input data constists of a list of 3 matrices. Matrix columns stand for pools and matrix rows for simulation time steps.
Usage
RothC_Cin_ex_sl_spin
Arguments
Format
A list of 3 matrices with 5 columns and 12 rows each